Abstract Rule class
===================
.. autoclass:: Rule.Rule
   :members:

Specific Rules
==============

Zone Rule
---------
.. autoclass:: Rule.ZoneRule
   :members:
   :show-inheritance:


Velocity Rule
-------------
.. autoclass:: Rule.VelocityRule
   :members:
   :show-inheritance:

Smooth Velocity Rule
--------------------
.. autoclass:: Rule.SmoothVelocityRule
   :members:
   :show-inheritance:

Speed Rule
----------
.. autoclass:: Rule.SpeedRule
   :members:
   :show-inheritance:

Keypress Rule
-------------
.. autoclass:: Rule.KeyPressRule
   :members:
   :show-inheritance:

Input Rule
----------
.. autoclass:: Rule.InputRule
   :members:
   :show-inheritance: